==> common-0.0.31-20200521.072040-1-sources.jar: com/ebaiyihui/doctor/ca/views/CenterHintDialog.java <==
package com.ebaiyihui.doctor.ca.views;

import android.content.Context;
import android.view.View;

import com.blankj.utilcode.util.StringUtils;
import com.kangxin.common.R;

public class CenterHintDialog {


    private Context mContext;
    private String title;
    private String rightText = StringUtils.getString(R.string.ca_quxiazai);
    private String leftText = StringUtils.getString(R.string.ca_quxiao);
    private String message;
    private View.OnClickListener clickCancel;
    private View.OnClickListener clickOk;

    private Boolean touchOutCancel = true;

    private boolean isShowCancel = true;

    private CenterHintDialog(Context mContext) {
        this.mContext = mContext;
    }

    public static CenterHintDialog with(Context mContext) {
        return new CenterHintDialog(mContext);
    }

    public CenterHintDialog setTitle(String title) {
        this.title = title;
        return this;
    }

    public CenterHintDialog setRightText(String rightText) {
        this.rightText = rightText;
        return this;
    }

    public CenterHintDialog setMesssage(String message) {
        this.message = message;
        return this;
    }

    public CenterHintDialog bindCancelClick(View.OnClickListener onClickListener) {
        this.clickCancel = onClickListener;
        return this;
    }

    public CenterHintDialog bindOkClick(View.OnClickListener onClickListener) {
        this.clickOk = onClickListener;
        return this;
    }

    public CenterHintDialog setShowCancel(boolean isShowCancel) {
        this.isShowCancel = isShowCancel;
        return this;
    }

    public CenterHintDialog setLeftText(String leftText) {
        this.leftText = leftText;
        return this;
    }


    public CenterHintDialog touchOutCancel(boolean isTouchCancel) {
        this.touchOutCancel = isTouchCancel;
        return this;
    }


    public void show() {

        new CenterHintDialogSpe(mContext)
                .bindLeftClick(clickCancel)
                .bindRightClick(clickOk)
                .setTouchOutCancel(touchOutCancel)
                .setShowCancel(isShowCancel)
                .setMessage(message)
                .setLeftText(leftText)
                .setTitle(title)
                .setRightText(rightText)
                .show();

    }

}

==> common-0.1.4-20211201.032514-1-sources.jar: com/ebaiyihui/doctor/ca/views/CenterHintDialog.java <==
package com.ebaiyihui.doctor.ca.views;

import android.content.Context;
import android.view.View;

import androidx.annotation.ColorInt;

import com.blankj.utilcode.util.StringUtils;
import com.kangxin.common.R;

public class CenterHintDialog {


    private Context mContext;
    private String title;
    private String rightText = StringUtils.getString(R.string.ca_quxiazai);
    private String leftText = StringUtils.getString(R.string.ca_quxiao);
    private String message;
    private View.OnClickListener clickCancel;
    private View.OnClickListener clickOk;
    private int color =-1;
    private Boolean touchOutCancel = true;

    private boolean isShowCancel = true;

    private CenterHintDialog(Context mContext) {
        this.mContext = mContext;
    }

    public static CenterHintDialog with(Context mContext) {
        return new CenterHintDialog(mContext);
    }

    public CenterHintDialog setTitle(String title) {
        this.title = title;
        return this;
    }

    public CenterHintDialog setTitleColor(@ColorInt int color) {
        this.color = color;
        return this;
    }

    public CenterHintDialog setRightText(String rightText) {
        this.rightText = rightText;
        return this;
    }

    public CenterHintDialog setMesssage(String message) {
        this.message = message;
        return this;
    }

    public CenterHintDialog bindCancelClick(View.OnClickListener onClickListener) {
        this.clickCancel = onClickListener;
        return this;
    }

    public CenterHintDialog bindOkClick(View.OnClickListener onClickListener) {
        this.clickOk = onClickListener;
        return this;
    }

    public CenterHintDialog setShowCancel(boolean isShowCancel) {
        this.isShowCancel = isShowCancel;
        return this;
    }

    public CenterHintDialog setLeftText(String leftText) {
        this.leftText = leftText;
        return this;
    }


    public CenterHintDialog touchOutCancel(boolean isTouchCancel) {
        this.touchOutCancel = isTouchCancel;
        return this;
    }


    public void show() {

        new CenterHintDialogSpe(mContext)
                .bindLeftClick(clickCancel)
                .bindRightClick(clickOk)
                .setTouchOutCancel(touchOutCancel)
                .setShowCancel(isShowCancel)
                .setMessage(message)
                .setLeftText(leftText)
                .setTitle(title)
                .setTitleColor(color)
                .setRightText(rightText)
                .show();

    }

}
